@@ -7,6 +7,7 @@
 #include "KBlocksSingleGame.h"
 #include "utils.h"
 #include <QRandomGenerator>
+#include <memory>
 
 KBlocksSingleGame::KBlocksSingleGame(int gameIndex, int fieldWidth, int fieldHeight, int showPieceCount, int messagePoolSize)
 {
@@ -120,11 +121,11 @@ int KBlocksSingleGame::punishGame(int lineCount, int punishSeed)
         mpGameRecorder->append(mGameIndex, RecordDataType_PunishLineSeed, punishSeed);
     }
 
+    QRandomGenerator randomGenerator(punishSeed);
     int punishIndex = 0;
-    auto random = QRandomGenerator::global();
     for (int i = 0; i < lineCount; i++) {
         setCurrentPiece(0, -1, 0);
-        punishIndex = random->bounded(width);
+        punishIndex = randomGenerator.bounded(width);
         mpField->addPunishLine(lineCount, punishIndex);
     }
 
@@ -140,8 +141,8 @@ bool KBlocksSingleGame::setCurrentPiece(int xPos, int yPos, int rotation)
     if ((mCurrentGameState != GameState_Running) || mStandbyFlag) {
         return false;
     }
-    //FIXME: new without delete (is the new really necessary here?)
-    QScopedPointer<KBlocksPiece> tmpPiece(new KBlocksPiece());
+
+    std::unique_ptr<KBlocksPiece> tmpPiece(new KBlocksPiece());
 
     tmpPiece->fromValue(mpPieceList[0]->toValue());
     tmpPiece->setPosX(mpPieceList[0]->getPosX() + xPos);
@@ -152,7 +153,7 @@ bool KBlocksSingleGame::setCurrentPiece(int xPos, int yPos, int rotation)
     }
     tmpPiece->setRotation(mpPieceList[0]->getRotation() + rotation);
 
-    if (checkPieceTouchGround(tmpPiece.data())) {
+    if (checkPieceTouchGround(tmpPiece.get())) {
         return false;
     }
 
